@ ECHO OFF

REM The Dynamic Discovery of Szip Encoder features is implemented in this batch file.
REM We do not need to manually set HDF5_SZIP_ENCODE environment variable.
REM We will check whether the SZIP library available includes encoder or not by 
REM calling the szip encoder detecting executable file testh5repack_detect_szip(dll).exe
REM and check the printed value.
REM If the printed value is "yes", then the SZIP library has encoder, HDF5_SZIP_ENCODE will be set as 1.
REM Otherwise,  HDF5_SZIP_ENCODE will be set as 0, and some tests will be skipped.

FOR /F "delims=" %%a in ('testfiles\testh5repack_detect_szip%2\%1\testh5repack_detect_szip%2.exe') Do Set "Output=%%a"
if "%Output%"=="yes" (
	Set HDF5_SZIP_ENCODE=1
)	else (
	Set HDF5_SZIP_ENCODE=0
)

REM testfiles\h5repacktst\%1\h5repacktst

mkdir temptest
type nul > temptest\empty.txt

REM Line removed to fix changes in h5repack
REM echo 0 differences found> temptest\empty.txt

REM h5repack_objs.h5 have some objects not comparable, which
REM will give more detailed output. 
type nul > temptest\ObjNotCom.txt
echo -------------------------------->temptest\ObjNotCom.txt
echo Some objects are not comparable>>temptest\ObjNotCom.txt
echo -------------------------------->>temptest\ObjNotCom.txt
echo Use -v for a list of objects.>>temptest\ObjNotCom.txt

echo -------------------------------->ObjNotCom.txt
echo Some objects are not comparable>>ObjNotCom.txt
echo -------------------------------->>ObjNotCom.txt
echo Use -v for a list of objects.>>ObjNotCom.txt
type nul > repacktest%2_%1.txt
echo ========================================== >> repacktest%2_%1.txt
echo Testing repacktest.bat >> repacktest%2_%1.txt
echo ========================================== >> repacktest%2_%1.txt

cd h5repack%2\%1

REM
REM The tests
REM We use the files generated by h5repack test
REM Each run generates "out.test*.h5" and the tool h5diff is used to
REM compare the input and output files.  The output from tool h5diff is 
REM redirected to a file, which should be an empty file when the input 
REM and output files are identical.  We can check whether the h5diff output
REM file is empty so we can know whether h5repack test passed.

REM copy files (these files have no filters; h5repack_attr.h5 has copied references that h5diff detects)
REM TOOLTEST h5repack_fill.h5
h5repack%2 -i ..\..\testfiles\h5repack_fill.h5 -o ..\..\temptest\out.h5repack_fill.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_fill.h5 ..\..\temptest\out.h5repack_fill.h5 > ..\..\temptest\h5repack_fill.results 2>..\..\temptest\h5repack_fill_error.results
more ..\..\temptest\h5repack_fill_error.results >> ..\..\temptest\h5repack_fill.results
fc ..\..\temptest\h5repack_fill.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_fill.h5                                                PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_fill.h5                                                FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_fill.h5
del ..\..\temptest\h5repack_fill.results
del ..\..\temptest\h5repack_fill_error.results

REM TOOLTEST h5repack_objs.h5
h5repack%2 -i ..\..\testfiles\h5repack_objs.h5 -o ..\..\temptest\out.h5repack_objs.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_objs.h5 ..\..\temptest\out.h5repack_objs.h5 > ..\..\temptest\h5repack_objs.results 2>..\..\temptest\h5repack_objs_error.results
more ..\..\temptest\h5repack_objs_error.results >> ..\..\temptest\h5repack_objs.results
FIND /V "0 differences found" ..\..\temptest\h5repack_objs.results >temp.txt
if %ERRORLEVEL%==0 (
fc ..\..\temptest\empty.txt ..\..\temptest\ObjNotCom.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_objs.h5                                                PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_objs.h5                                                FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
)
del temp.txt
del ..\..\temptest\out.h5repack_objs.h5
del ..\..\temptest\h5repack_objs.results
del ..\..\temptest\h5repack_objs_error.results

REM TOOLTEST h5repack_attr.h5
h5repack%2 -i ..\..\testfiles\h5repack_attr.h5 -o ..\..\temptest\out.h5repack_attr.h5 
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_attr.h5 ..\..\temptest\out.h5repack_attr.h5 > ..\..\temptest\h5repack_attr.results 2>..\..\temptest\h5repack_attr_error.results
more ..\..\temptest\h5repack_attr_error.results >> ..\..\temptest\h5repack_attr.results
fc ..\..\temptest\h5repack_attr.results ..\..\temptest\ObjNotCom.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_attr.h5                                                PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_attr.h5                                                FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_attr.h5
del ..\..\temptest\h5repack_attr.results
del ..\..\temptest\h5repack_attr_error.results

REM TOOLTEST h5repack_hlink.h5
h5repack%2 -i ..\..\testfiles\h5repack_hlink.h5 -o ..\..\temptest\out.h5repack_hlink.h5 
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_hlink.h5 ..\..\temptest\out.h5repack_hlink.h5 > ..\..\temptest\h5repack_hlink.results 2>..\..\temptest\h5repack_hlink_error.results
more ..\..\temptest\h5repack_hlink_error.results >> ..\..\temptest\h5repack_hlink.results
fc ..\..\temptest\h5repack_hlink.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_hlink.h5                                               PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_hlink.h5                                               FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_hlink.h5
del ..\..\temptest\h5repack_hlink.results
del ..\..\temptest\h5repack_hlink_error.results

REM TOOLTEST h5repack_layout.h5
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5                                              PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5                                              FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_early.h5
h5repack%2 -i ..\..\testfiles\h5repack_early.h5 -o ..\..\temptest\out.h5repack_early.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_early.h5 ..\..\temptest\out.h5repack_early.h5 > ..\..\temptest\h5repack_early.results 2>..\..\temptest\h5repack_early_error.results
more ..\..\temptest\h5repack_early_error.results >> ..\..\temptest\h5repack_early.results
fc ..\..\temptest\h5repack_early.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_early.h5                                               PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_early.h5                                               FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_early.h5
del ..\..\temptest\h5repack_early.results
del ..\..\temptest\h5repack_early_error.results


REM use h5repack_layout.h5 to write some filters (this file has no filters)

REM gzip with individual object
REM TOOLTEST h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP1
if %HDF5_EXT_ZLIB%==zdll.lib (
    h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10
    ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
    more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
    fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
    if %ERRORLEVEL%==0 (
       echo Testing h5repack h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10        PASSED >> ..\..\repacktest%2_%1.txt
    ) else (
        echo Testing h5repack h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10        FAILED >> ..\..\repacktest%2_%1.txt
        more temp.txt >> ..\..\repacktest%2_%1.txt
    )
    del temp.txt
    del ..\..\temptest\out.h5repack_layout.h5
    del ..\..\temptest\h5repack_layout.results
    del ..\..\temptest\h5repack_layout_error.results
    GOTO NEXTSTEP2
) else (
    echo Testing h5repack h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10        -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP2
)

:NEXTSTEP1
echo Testing h5repack h5repack_layout.h5 -f dset1:GZIP=1  -l dset1:CHUNK=20x10        -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP2

REM gzip for all
REM TOOLTEST h5repack_layout.h5 -f GZIP=1
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP3
if %HDF5_EXT_ZLIB%==zdll.lib (
    h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f GZIP=1
    ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
    more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
    fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
    if %ERRORLEVEL%==0 (
       echo Testing h5repack h5repack_layout.h5 -f GZIP=1                                    PASSED >> ..\..\repacktest%2_%1.txt
    ) else (
        echo Testing h5repack h5repack_layout.h5 -f GZIP=1                                    FAILED >> ..\..\repacktest%2_%1.txt
        more temp.txt >> ..\..\repacktest%2_%1.txt
    )
    del temp.txt
    del ..\..\temptest\out.h5repack_layout.h5
    del ..\..\temptest\h5repack_layout.results
    del ..\..\temptest\h5repack_layout_error.results
    GOTO NEXTSTEP4
) else (
    echo Testing h5repack h5repack_layout.h5 -f GZIP=1                                    -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP4
)

:NEXTSTEP3
echo Testing h5repack h5repack_layout.h5 -f GZIP=1                                    -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP4

REM szip with individual object
REM TOOLTEST h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP5
if %HDF5_EXT_SZIP%==szlibdll.lib (
   if %HDF5_SZIP_ENCODE%==1 (
      h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10
      ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
      more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
      fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
      if %ERRORLEVEL%==0 (
         echo Testing h5repack h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10     PASSED >> ..\..\repacktest%2_%1.txt
      ) else (
          echo Testing h5repack h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10     FAILED >> ..\..\repacktest%2_%1.txt
          more temp.txt >> ..\..\repacktest%2_%1.txt
      )
      del temp.txt
      del ..\..\temptest\out.h5repack_layout.h5
      del ..\..\temptest\h5repack_layout.results
      del ..\..\temptest\h5repack_layout_error.results
      GOTO NEXTSTEP6
      ) else (
          echo Testing h5repack h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10     -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP6
      )
) else (
    echo Testing h5repack h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10     -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP6
)

:NEXTSTEP5
echo Testing h5repack h5repack_layout.h5 -f dset2:SZIP=8,EC  -l dset2:CHUNK=20x10     -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP6

REM szip for all
REM TOOLTEST h5repack_layout.h5 -f SZIP=8,NN
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP7
if %HDF5_EXT_SZIP%==szlibdll.lib (
   if %HDF5_SZIP_ENCODE%==1 (
      h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f SZIP=8,NN
      ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
      more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
      fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
      if %ERRORLEVEL%==0 (
         echo Testing h5repack h5repack_layout.h5 -f SZIP=8,NN                                 PASSED >> ..\..\repacktest%2_%1.txt
      ) else (
          echo Testing h5repack h5repack_layout.h5 -f SZIP=8,NN                                 FAILED >> ..\..\repacktest%2_%1.txt
          more temp.txt >> ..\..\repacktest%2_%1.txt
      )
      del temp.txt
      del ..\..\temptest\out.h5repack_layout.h5
      del ..\..\temptest\h5repack_layout.results
      del ..\..\temptest\h5repack_layout_error.results
      GOTO NEXTSTEP8
      ) else (
          echo Testing h5repack h5repack_layout.h5 -f SZIP=8,NN                                 -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP8
      )
) else (
    echo Testing h5repack h5repack_layout.h5 -f SZIP=8,NN                                 -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP8
)

:NEXTSTEP7
echo Testing h5repack h5repack_layout.h5 -f SZIP=8,NN                                 -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP8

REM shuffle with individual object
REM TOOLTEST h5repack_layout.h5 -f dset2:SHUF  -l dset2:CHUNK=20x10
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f dset2:SHUF  -l dset2:CHUNK=20x10
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF  -l dset2:CHUNK=20x10          PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF  -l dset2:CHUNK=20x10          FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM shuffle for all
REM TOOLTEST h5repack_layout.h5 -f SHUF
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f SHUF
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -f SHUF                                      PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -f SHUF                                      FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM fletcher32  with individual object
REM TOOLTEST h5repack_layout.h5 -f dset2:FLET  -l dset2:CHUNK=20x10
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f dset2:FLET  -l dset2:CHUNK=20x10
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -f dset2:FLET  -l dset2:CHUNK=20x10          PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -f dset2:FLET  -l dset2:CHUNK=20x10          FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM fletcher32 for all
REM TOOLTEST h5repack_layout.h5 -f FLET
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f FLET
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -f FLET                                      PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -f FLET                                      FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM all filters
REM TOOLTEST h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8,NN -f dset2:GZIP=1 -l dset2:CHUNK=20x10
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP9
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP9
if %HDF5_EXT_ZLIB%==zdll.lib (
   if %HDF5_EXT_SZIP%==szlibdll.lib (
      if %HDF5_SZIP_ENCODE%==1 (
         h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f dset2:SZIP=8,NN -f dset2:GZIP=1 -l dset2:CHUNK=20x10
         ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
         more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
         fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
         if %ERRORLEVEL%==0 (
            echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, PASSED >> ..\..\repacktest%2_%1.txt
         ) else (
             echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, FAILED >> ..\..\repacktest%2_%1.txt
             more temp.txt >> ..\..\repacktest%2_%1.txt
         )
         del temp.txt
         del ..\..\temptest\out.h5repack_layout.h5
         del ..\..\temptest\h5repack_layout.results
         del ..\..\temptest\h5repack_layout_error.results
         GOTO NEXTSTEP10
         ) else (
             echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, -SKIP- >> ..\..\repacktest%2_%1.txt
             GOTO NEXTSTEP10
         )
      ) else (
          echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP10
      )
) else (
    echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP10
)

:NEXTSTEP9
echo Testing h5repack h5repack_layout.h5 -f dset2:SHUF -f dset2:FLET -f dset2:SZIP=8, -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP10

REM ###########################################################
REM # the following tests assume the input files have filters
REM ###########################################################

REM szip copy
REM TOOLTEST h5repack_szip.h5
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP11
if %HDF5_EXT_SZIP%==szlibdll.lib (
   if %HDF5_SZIP_ENCODE%==1 (
      h5repack%2 -i ..\..\testfiles\h5repack_szip.h5 -o ..\..\temptest\out.h5repack_szip.h5
      ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_szip.h5 ..\..\temptest\out.h5repack_szip.h5 > ..\..\temptest\h5repack_szip.results 2>..\..\temptest\h5repack_szip_error.results
      more ..\..\temptest\h5repack_szip_error.results >> ..\..\temptest\h5repack_szip.results
      fc ..\..\temptest\h5repack_szip.results ..\..\temptest\empty.txt >temp.txt
      if %ERRORLEVEL%==0 (
         echo Testing h5repack h5repack_szip.h5                                                PASSED >> ..\..\repacktest%2_%1.txt
      ) else (
         echo Testing h5repack h5repack_szip.h5                                                FAILED >> ..\..\repacktest%2_%1.txt
         more temp.txt >> ..\..\repacktest%2_%1.txt
      )
      del temp.txt
      del ..\..\temptest\out.h5repack_szip.h5
      del ..\..\temptest\h5repack_szip.results
      del ..\..\temptest\h5repack_szip_error.results
      GOTO NEXTSTEP12
      ) else (
          echo Testing h5repack h5repack_szip.h5                                                -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP12
      )
) else (
    echo Testing h5repack h5repack_szip.h5                                          -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP12
)

:NEXTSTEP11
echo Testing h5repack h5repack_szip.h5                                                -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP12
  
REM szip remove
REM TOOLTEST h5repack_szip.h5 -f dset_szip:NONE
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP13
if %HDF5_EXT_SZIP%==szlibdll.lib (
   if %HDF5_SZIP_ENCODE%==1 (
      h5repack%2 -i ..\..\testfiles\h5repack_szip.h5 -o ..\..\temptest\out.h5repack_szip.h5 -f dset_szip:NONE
      ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_szip.h5 ..\..\temptest\out.h5repack_szip.h5 > ..\..\temptest\h5repack_szip.results 2>..\..\temptest\h5repack_szip_error.results
      more ..\..\temptest\h5repack_szip_error.results >> ..\..\temptest\h5repack_szip.results
      fc ..\..\temptest\h5repack_szip.results ..\..\temptest\empty.txt >temp.txt
      if %ERRORLEVEL%==0 (
         echo Testing h5repack h5repack_szip.h5 -f dset_szip:NONE                              PASSED >> ..\..\repacktest%2_%1.txt
      ) else (
         echo Testing h5repack h5repack_szip.h5 -f dset_szip:NONE                              FAILED >> ..\..\repacktest%2_%1.txt
         more temp.txt >> ..\..\repacktest%2_%1.txt
      )
      del temp.txt
      del ..\..\temptest\out.h5repack_szip.h5
      del ..\..\temptest\h5repack_szip.results
      del ..\..\temptest\h5repack_szip_error.results
      GOTO NEXTSTEP14
      ) else (
          echo Testing h5repack h5repack_szip.h5 -f dset_szip:NONE                        -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP14
      )
) else (
    echo Testing h5repack h5repack_szip.h5 -f dset_szip:NONE                        -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP14
)

:NEXTSTEP13
echo Testing h5repack h5repack_szip.h5 -f dset_szip:NONE                        -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP14
  
REM deflate copy
REM TOOLTEST h5repack_deflate.h5
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP15
if %HDF5_EXT_ZLIB%==zdll.lib (
   h5repack%2 -i ..\..\testfiles\h5repack_deflate.h5 -o ..\..\temptest\out.h5repack_deflate.h5
   ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_deflate.h5 ..\..\temptest\out.h5repack_deflate.h5 > ..\..\temptest\h5repack_deflate.results 2>..\..\temptest\h5repack_deflate_error.results
   more ..\..\temptest\h5repack_deflate_error.results >> ..\..\temptest\h5repack_deflate.results
   fc ..\..\temptest\h5repack_deflate.results ..\..\temptest\empty.txt >temp.txt
   if %ERRORLEVEL%==0 (
      echo Testing h5repack h5repack_deflate.h5                                             PASSED >> ..\..\repacktest%2_%1.txt
   ) else (
      echo Testing h5repack h5repack_deflate.h5                                             FAILED >> ..\..\repacktest%2_%1.txt
      more temp.txt >> ..\..\repacktest%2_%1.txt
   )
   del temp.txt
   del ..\..\temptest\out.h5repack_deflate.h5
   del ..\..\temptest\h5repack_deflate.results
   del ..\..\temptest\h5repack_deflate_error.results
   GOTO NEXTSTEP16
) else (
    echo Testing h5repack h5repack_deflate.h5                                             -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP16
)

:NEXTSTEP15
echo Testing h5repack h5repack_deflate.h5                                             -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP16

REM deflate remove
REM TOOLTEST h5repack_deflate.h5 -f dset_deflate:NONE
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP17
if %HDF5_EXT_ZLIB%==zdll.lib (
   h5repack%2 -i ..\..\testfiles\h5repack_deflate.h5 -o ..\..\temptest\out.h5repack_deflate.h5 -f dset_deflate:NONE
   ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_deflate.h5 ..\..\temptest\out.h5repack_deflate.h5 > ..\..\temptest\h5repack_deflate.results 2>..\..\temptest\h5repack_deflate_error.results
   more ..\..\temptest\h5repack_deflate_error.results >> ..\..\temptest\h5repack_deflate.results
   fc ..\..\temptest\h5repack_deflate.results ..\..\temptest\empty.txt >temp.txt
   if %ERRORLEVEL%==0 (
      echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:NONE                        PASSED >> ..\..\repacktest%2_%1.txt
   ) else (
      echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:NONE                        FAILED >> ..\..\repacktest%2_%1.txt
      more temp.txt >> ..\..\repacktest%2_%1.txt
   )
   del temp.txt
   del ..\..\temptest\out.h5repack_deflate.h5
   del ..\..\temptest\h5repack_deflate.results
   del ..\..\temptest\h5repack_deflate_error.results
   GOTO NEXTSTEP18
) else (
    echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:NONE                        -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP18
)

:NEXTSTEP17
echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:NONE                        -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP18
   
REM shuffle copy
REM TOOLTEST h5repack_shuffle.h5
h5repack%2 -i ..\..\testfiles\h5repack_shuffle.h5 -o ..\..\temptest\out.h5repack_shuffle.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_shuffle.h5 ..\..\temptest\out.h5repack_shuffle.h5 > ..\..\temptest\h5repack_shuffle.results 2>..\..\temptest\h5repack_shuffle_error.results
more ..\..\temptest\h5repack_shuffle_error.results >> ..\..\temptest\h5repack_shuffle.results
fc ..\..\temptest\h5repack_shuffle.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_shuffle.h5                                             PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_shuffle.h5                                             FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_shuffle.h5
del ..\..\temptest\h5repack_shuffle.results
del ..\..\temptest\h5repack_shuffle_error.results

REM shuffle remove
REM TOOLTEST h5repack_shuffle.h5 -f dset_shuffle:NONE
h5repack%2 -i ..\..\testfiles\h5repack_shuffle.h5 -o ..\..\temptest\out.h5repack_shuffle.h5 -f dset_shuffle:NONE
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_shuffle.h5 ..\..\temptest\out.h5repack_shuffle.h5 > ..\..\temptest\h5repack_shuffle.results 2>..\..\temptest\h5repack_shuffle_error.results
more ..\..\temptest\h5repack_shuffle_error.results >> ..\..\temptest\h5repack_shuffle.results
fc ..\..\temptest\h5repack_shuffle.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_shuffle.h5 -f dset_shuffle:NONE                        PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_shuffle.h5 -f dset_shuffle:NONE                        FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_shuffle.h5
del ..\..\temptest\h5repack_shuffle.results
del ..\..\temptest\h5repack_shuffle_error.results

REM fletcher32 copy
REM TOOLTEST h5repack_fletcher.h5
h5repack%2 -i ..\..\testfiles\h5repack_fletcher.h5 -o ..\..\temptest\out.h5repack_fletcher.h5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_fletcher.h5 ..\..\temptest\out.h5repack_fletcher.h5 > ..\..\temptest\h5repack_fletcher.results 2>..\..\temptest\h5repack_fletcher_error.results
more ..\..\temptest\h5repack_fletcher_error.results >> ..\..\temptest\h5repack_fletcher.results
fc ..\..\temptest\h5repack_fletcher.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_fletcher.h5                                            PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_fletcher.h5                                            FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_fletcher.h5
del ..\..\temptest\h5repack_fletcher.results
del ..\..\temptest\h5repack_fletcher_error.results

REM fletcher32 remove
REM TOOLTEST h5repack_fletcher.h5 -f dset_fletcher32:NONE
h5repack%2 -i ..\..\testfiles\h5repack_fletcher.h5 -o ..\..\temptest\out.h5repack_fletcher.h5 -f dset_fletcher32:NONE
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_fletcher.h5 ..\..\temptest\out.h5repack_fletcher.h5 > ..\..\temptest\h5repack_fletcher.results 2>..\..\temptest\h5repack_fletcher_error.results
more ..\..\temptest\h5repack_fletcher_error.results >> ..\..\temptest\h5repack_fletcher.results
fc ..\..\temptest\h5repack_fletcher.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_fletcher.h5 -f dset_fletcher32:NONE                    PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_fletcher.h5 -f dset_fletcher32:NONE                    FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_fletcher.h5
del ..\..\temptest\h5repack_fletcher.results
del ..\..\temptest\h5repack_fletcher_error.results

REM remove all  filters
REM TOOLTEST h5repack_filters.h5 -f NONE
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP19
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP19
if %HDF5_EXT_ZLIB%==zdll.lib (
   if %HDF5_EXT_SZIP%==szlibdll.lib (
      if %HDF5_SZIP_ENCODE%==1 (
         h5repack%2 -i ..\..\testfiles\h5repack_filters.h5 -o ..\..\temptest\out.h5repack_filters.h5 -f NONE
         ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_filters.h5 ..\..\temptest\out.h5repack_filters.h5 > ..\..\temptest\h5repack_filters.results 2>..\..\temptest\h5repack_filters_error.results
         more ..\..\temptest\h5repack_filters_error.results >> ..\..\temptest\h5repack_filters.results
         fc ..\..\temptest\h5repack_filters.results ..\..\temptest\empty.txt >temp.txt
         if %ERRORLEVEL%==0 (
            echo Testing h5repack h5repack_filters.h5 -f NONE                                     PASSED >> ..\..\repacktest%2_%1.txt
         ) else (
            echo Testing h5repack h5repack_filters.h5 -f NONE                                     FAILED >> ..\..\repacktest%2_%1.txt
            more temp.txt >> ..\..\repacktest%2_%1.txt
         )
         del temp.txt
         del ..\..\temptest\out.h5repack_filters.h5
         del ..\..\temptest\h5repack_filters.results
         del ..\..\temptest\h5repack_filters_error.results
         GOTO NEXTSTEP20
         ) else (
             echo Testing h5repack h5repack_filters.h5 -f NONE                                     -SKIP- >> ..\..\repacktest%2_%1.txt
             GOTO NEXTSTEP20
         )
      ) else (
          echo Testing h5repack h5repack_filters.h5 -f NONE                                     -SKIP- >> ..\..\repacktest%2_%1.txt
          GOTO NEXTSTEP20
      )
) else (
    echo Testing h5repack h5repack_filters.h5 -f NONE                                   -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP20
)

:NEXTSTEP19
echo Testing h5repack h5repack_objs1.h5 -f NONE                                   -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP20

REM filter conversions
REM TOOLTEST h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP21
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP21
if %HDF5_EXT_ZLIB%==zdll.lib (
   if %HDF5_EXT_SZIP%==szlibdll.lib (
      if %HDF5_SZIP_ENCODE%==1 (
         h5repack%2 -i ..\..\testfiles\h5repack_deflate.h5 -o ..\..\temptest\out.h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN
         ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_deflate.h5 ..\..\temptest\out.h5repack_deflate.h5 > ..\..\temptest\h5repack_deflate.results 2>..\..\temptest\h5repack_deflate_error.results
         more ..\..\temptest\h5repack_deflate_error.results >> ..\..\temptest\h5repack_deflate.results
         fc ..\..\temptest\h5repack_deflate.results ..\..\temptest\empty.txt >temp.txt
         if %ERRORLEVEL%==0 (
            echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   PASSED >> ..\..\repacktest%2_%1.txt
         ) else (
            echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   FAILED >> ..\..\repacktest%2_%1.txt
            more temp.txt >> ..\..\repacktest%2_%1.txt
         )
         del temp.txt
         del ..\..\temptest\out.h5repack_deflate.h5
         del ..\..\temptest\h5repack_deflate.results
         del ..\..\temptest\h5repack_deflate_error.results
         GOTO NEXTSTEP22
      ) else (
         echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   -SKIP- >> ..\..\repacktest%2_%1.txt
         GOTO NEXTSTEP22
      )
   ) else (
      echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   -SKIP- >> ..\..\repacktest%2_%1.txt
      GOTO NEXTSTEP22
   )
) else (
    echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP22
)

:NEXTSTEP21
echo Testing h5repack h5repack_deflate.h5 -f dset_deflate:SZIP=8,NN                   -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP22
  
REM TOOLTEST h5repack_szip.h5 -f dset_szip:GZIP=1
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP23
if "%HDF5_EXT_SZIP%"=="" GOTO NEXTSTEP23
if %HDF5_EXT_ZLIB%==zdll.lib (
   if %HDF5_EXT_SZIP%==szlibdll.lib (
      if %HDF5_SZIP_ENCODE%==1 (
         h5repack%2 -i ..\..\testfiles\h5repack_szip.h5 -o ..\..\temptest\out.h5repack_szip.h5 -f dset_szip:GZIP=1
         ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_szip.h5 ..\..\temptest\out.h5repack_szip.h5 > ..\..\temptest\h5repack_szip.results 2>..\..\temptest\h5repack_szip_error.results
         more ..\..\temptest\h5repack_szip_error.results >> ..\..\temptest\h5repack_szip.results
         fc ..\..\temptest\h5repack_szip.results ..\..\temptest\empty.txt >temp.txt
         if %ERRORLEVEL%==0 (
            echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            PASSED >> ..\..\repacktest%2_%1.txt
         ) else (
            echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            FAILED >> ..\..\repacktest%2_%1.txt
            more temp.txt >> ..\..\repacktest%2_%1.txt
         )
         del temp.txt
         del ..\..\temptest\out.h5repack_szip.h5
         del ..\..\temptest\h5repack_szip.results
         del ..\..\temptest\h5repack_szip_error.results
         GOTO NEXTSTEP24
      ) else (
         echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            -SKIP- >> ..\..\repacktest%2_%1.txt
         GOTO NEXTSTEP24
      )
   ) else (
      echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            -SKIP- >> ..\..\repacktest%2_%1.txt
      GOTO NEXTSTEP24
   )
) else (
    echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP24
)

:NEXTSTEP23
echo Testing h5repack h5repack_szip.h5 -f dset_szip:GZIP=1                            -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP24
  
REM limit
REM TOOLTEST h5repack_layout.h5 -f GZIP=1 -m 1024
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP25
if %HDF5_EXT_ZLIB%==zdll.lib (
   h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -f GZIP=1 -m 1024
   ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
   more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
   fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
   if %ERRORLEVEL%==0 (
      echo Testing h5repack h5repack_layout.h5 -f GZIP=1 -m 1024                            PASSED >> ..\..\repacktest%2_%1.txt
   ) else (
      echo Testing h5repack h5repack_layout.h5 -f GZIP=1 -m 1024                            FAILED >> ..\..\repacktest%2_%1.txt
      more temp.txt >> ..\..\repacktest%2_%1.txt
   )
   del temp.txt
   del ..\..\temptest\out.h5repack_layout.h5
   del ..\..\temptest\h5repack_layout.results
   del ..\..\temptest\h5repack_layout_error.results
   GOTO NEXTSTEP26
) else (
    echo Testing h5repack h5repack_layout.h5 -f GZIP=1 -m 1024                            -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP26
)

:NEXTSTEP25
echo Testing h5repack h5repack_layout.h5 -f GZIP=1 -m 1024                            -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP26
    
REM file
REM TOOLTEST h5repack_layout.h5 -e ../testfiles/info.h5repack
if "%HDF5_EXT_ZLIB%"=="" GOTO NEXTSTEP27
if %HDF5_EXT_ZLIB%==zdll.lib (
   h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -e ..\..\testfiles\info.h5repack
   ..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
   more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
   fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
   if %ERRORLEVEL%==0 (
      echo Testing h5repack h5repack_layout.h5 -e ../testfiles/info.h5repack                PASSED >> ..\..\repacktest%2_%1.txt
   ) else (
      echo Testing h5repack h5repack_layout.h5 -e ../testfiles/info.h5repack                FAILED >> ..\..\repacktest%2_%1.txt
      more temp.txt >> ..\..\repacktest%2_%1.txt
   )
   del temp.txt
   del ..\..\temptest\out.h5repack_layout.h5
   del ..\..\temptest\h5repack_layout.results
   del ..\..\temptest\h5repack_layout_error.results
   GOTO NEXTSTEP28
) else (
    echo Testing h5repack h5repack_layout.h5 -e ../testfiles/info.h5repack                -SKIP- >> ..\..\repacktest%2_%1.txt
    GOTO NEXTSTEP28
)

:NEXTSTEP27
echo Testing h5repack h5repack_layout.h5 -e ../testfiles/info.h5repack                -SKIP- >> ..\..\repacktest%2_%1.txt

:NEXTSTEP28
   
REM layout chunk
REM TOOLTEST h5repack_layout.h5 -l dset2:CHUNK=20x10
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset2:CHUNK=20x10
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset2:CHUNK=20x10                         PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset2:CHUNK=20x10                         FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l CHUNK=20x10
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l CHUNK=20x10
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l CHUNK=20x10                               PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l CHUNK=20x10                               FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM layout contiguous
REM TOOLTEST h5repack_layout.h5 -l dset2:CONTI
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset2:CONTI
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset2:CONTI                               PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset2:CONTI                               FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l CONTI
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l CONTI
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l CONTI                                     PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l CONTI                                     FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM layout compact
REM TOOLTEST h5repack_layout.h5 -l dset2:COMPA
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset2:COMPA
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset2:COMPA                               PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset2:COMPA                               FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l COMPA
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l COMPA
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l COMPA                                     PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l COMPA                                     FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM layout conversions

REM TOOLTEST h5repack_layout.h5 -l dset_compact:CONTI
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_compact:CONTI
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:CONTI                        PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:CONTI                        FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_compact:CHUNK=2x5
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_compact:CHUNK=2x5
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:CHUNK=2x5                    PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:CHUNK=2x5                    FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_compact:COMPA
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_compact:COMPA
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:COMPA                        PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_compact:COMPA                        FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_contiguous:COMPA
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_contiguous:COMPA
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:COMPA                     PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:COMPA                     FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_contiguous:CHUNK=3x6
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_contiguous:CHUNK=3x6
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:CHUNK=3x6                 PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:CHUNK=3x6                 FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_contiguous:CONTI
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_contiguous:CONTI
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:CONTI                     PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_contiguous:CONTI                     FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_chunk:COMPA
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_chunk:COMPA
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:COMPA                          PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:COMPA                          FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_chunk:CONTI
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_chunk:CONTI
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:CONTI                          PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:CONTI                          FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

REM TOOLTEST h5repack_layout.h5 -l dset_chunk:CHUNK=18x13
h5repack%2 -i ..\..\testfiles\h5repack_layout.h5 -o ..\..\temptest\out.h5repack_layout.h5 -l dset_chunk:CHUNK=18x13
..\..\h5diff%2\%1\h5diff%2 ..\..\testfiles\h5repack_layout.h5 ..\..\temptest\out.h5repack_layout.h5 > ..\..\temptest\h5repack_layout.results 2>..\..\temptest\h5repack_layout_error.results
more ..\..\temptest\h5repack_layout_error.results >> ..\..\temptest\h5repack_layout.results
fc ..\..\temptest\h5repack_layout.results ..\..\temptest\empty.txt >temp.txt
if %ERRORLEVEL%==0 (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:CHUNK=18x13                    PASSED >> ..\..\repacktest%2_%1.txt
) else (
   echo Testing h5repack h5repack_layout.h5 -l dset_chunk:CHUNK=18x13                    FAILED >> ..\..\repacktest%2_%1.txt
   more temp.txt >> ..\..\repacktest%2_%1.txt
)
del temp.txt
del ..\..\temptest\out.h5repack_layout.h5
del ..\..\temptest\h5repack_layout.results
del ..\..\temptest\h5repack_layout_error.results

cd ..
cd ..

rmdir /s/q temptest